@@ -194,6 +194,24 @@ class Device:
             self.fki_project_id = data['fki_project_id']
 
 
+class Spacetime:
+    def __init__(self):
+        self.pki = None
+        self.uint32_t_created = None
+        self.point_position = None
+        self.fk_uuid = None
+
+    def from_json(self, data):
+        if 'pki' in data:
+            self.pki = data['pki']
+        if 'uint32_t_created' in data:
+            self.uint32_t_created = data['uint32_t_created']
+        if 'point_position' in data:
+            self.point_position = data['point_position']
+        if 'fk_uuid' in data:
+            self.fk_uuid = data['fk_uuid']
+
+
 class FramesManager:
     def __init__(self):
         self.url = 'https://api.spothole.sensorit.io'
@@ -235,6 +253,20 @@ class FramesManager:
             print('Failed with code:', response.status_code)
             return {'code': response.status_code}
 
+    def _put(self, uri, params=None) -> dict:
+        headers = {
+            'content-type': 'application/json',
+            'x-access-tokens': self.jwt
+        }
+
+        response = requests.put(uri, headers=headers, params=params)
+
+        if response.status_code == 200:
+            return response.json()
+        else:
+            print('Failed with code:', response.status_code)
+            return {'code': response.status_code}
+
     def get_record(self, pki: str) -> Record:
         uri = "{}/record/{}".format(self.url, pki)
 
@@ -270,6 +302,19 @@ class FramesManager:
         d.from_json(self._get(uri))
         return d
 
+    def get_spacetime(self, uuid: str) -> Spacetime:
+        uri = "{}/spacetime/{}".format(self.url, uuid)
+
+        s = Spacetime()
+        s.from_json(self._get(uri))
+        return s
+
+    def put_spacetime(self, uuid: str, lat: float, lon: float) -> Spacetime:
+        uri = "{}/spacetime/{}".format(self.url, uuid)
+        params = {'lat': lat, 'lon': lon}
+
+        return self._put(uri, params)
+
 
 if __name__ == "__main__":
     fm = FramesManager()
